@@ -190,7 +190,9 @@ class Petisco(metaclass=Singleton):
             self.task_executor.start(config_tasks)
 
     def _unschedule_tasks(self):
-        self.task_executor.stop()
+        config_tasks = self.config.config_tasks
+        if config_tasks.tasks:
+            self.task_executor.stop()
 
     def _set_persistence(self):
         self._persistence_models = {}
@@ -305,11 +307,15 @@ class Petisco(metaclass=Singleton):
 
     def start(self):
         self._start()
-        self.config.get_application().start()
+        self._application.start()
 
     def get_app(self):
         self._start()
-        return self.config.get_application().get_app()
+        self._application = self.config.get_application()
+        return self._application.get_app()
+
+    def get_application(self):
+        return self._application
 
     def stop(self):
         self.event_subscriber.stop()
